* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Pace Layering Framework](https://help.sap.com/docs/leanix/ea/pace-layering)
  * Application of Pace Layering in Assessments
